==> haskell-loop-0.3.0-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-loop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: loop
version: 0.3.0
id: loop-0.3.0-2wV0p7f2S6e9aQdaxANYwr
key: loop-0.3.0-2wV0p7f2S6e9aQdaxANYwr
license: MIT
copyright: 2014 Niklas Hambüchen <mail@nh2.me>
maintainer: Niklas Hambüchen <mail@nh2.me>
author: Niklas Hambüchen <mail@nh2.me>
stability: experimental
homepage: https://github.com/nh2/loop
synopsis: Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.
    .
    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.
category: Control
abi: 04c4e16997e326f9e2e00b393566f1c6
exposed: True
exposed-modules:
    Control.Loop Control.Loop.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/loop-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/loop-0.3.0
hs-libraries: HSloop-0.3.0-2wV0p7f2S6e9aQdaxANYwr
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html: /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-loop-0.3.0-28-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-loop.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: loop
version: 0.3.0
id: loop-0.3.0-IDnilDj74FC5raRVUBUuoZ
key: loop-0.3.0-IDnilDj74FC5raRVUBUuoZ
license: MIT
copyright: 2014 Niklas Hambüchen <mail@nh2.me>
maintainer: Niklas Hambüchen <mail@nh2.me>
author: Niklas Hambüchen <mail@nh2.me>
stability: experimental
homepage: https://github.com/nh2/loop
synopsis: Fast loops (for when GHC can'\''t optimize forM_)
description:
    This package provides a convenient and fast alternative to the common
    `forM_ [1..n]` idiom, which in many cases GHC cannot fuse to efficient
    code.
    .
    See <https://ghc.haskell.org/trac/ghc/ticket/8763>.
category: Control
abi: 3a594bd095beffc4b1a7a218be83e784
exposed: True
exposed-modules:
    Control.Loop Control.Loop.Internal
import-dirs: /usr/lib/ghc-8.6.5/site-local/loop-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/loop-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/loop-0.3.0
hs-libraries: HSloop-0.3.0-IDnilDj74FC5raRVUBUuoZ
depends:
    base-4.12.0.0
haddock-interfaces: /usr/share/doc/haskell-loop/html/loop.haddock
haddock-html: /usr/share/doc/haskell-loop/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
